# Ether

[![GitHub license](https://img.shields.io/badge/license-MIT-blue.svg)](https://github.com/0xver/ether/blob/master/LICENSE.md)

Ether is a minimalistic wallet CLI for basic Ethereum transactions and more. Encrypt a mnemonic onto an external drive then use it with a passphrase to securely derive keys and manage ETH.

#

## Source
Clone ether
```
gh repo clone 0xver/ether
```
Install ether
```
pip install .
```

#

## PyPi
Install ether
```
pip install ether-cli
```

#

## Getting Started
Check version
```
ether
```
Setup wallet
```
ether init
```
List all available commands
```
ether commands
```